@@ -18,23 +18,20 @@ MISSING = -99999
 def _is_missing_value(value): return value == MISSING_VALUE or value == MISSING or value == str(MISSING)
 
 
-def _replace_missing_values(value: str):
-    value = value.replace(f"{DELIMITER}{MISSING_VALUE}", f"{DELIMITER}{MISSING}")
-    # handle missing value at begining of the row
-    return value.replace(MISSING_VALUE, str(MISSING), 1) if value.startswith(MISSING_VALUE) else value
+def _replace_missing_values(value: str): return str(MISSING) if str(value) == '-' else value
 
 
 def _rewrite_csv_file_as_tab(filepath: str):
     with open(filepath, 'r', encoding=ENCODING) as fp:
         reader = csv.reader(fp)
         for row in reader:
-            yield _replace_missing_values(DELIMITER.join(row))
+            yield DELIMITER.join(list(map(_replace_missing_values, row)))
 
 
 def _rewrite_csv_text_as_tab(text: str):
     reader = csv.reader(StringIO(text))
     for row in reader:
-        yield _replace_missing_values(DELIMITER.join(row))
+        yield DELIMITER.join(list(map(_replace_missing_values, row)))
 
 
 def _recfromcsv(data): return numpy.recfromcsv(data,
